# pyDatum
Set of datetime tools in Python, similar to Joda Time or Calendar

This is a library that provides convenient operations on datetime objects in Python.

## Publish 

To publish the package, run

### Test Site

```console
python setup.py sdist upload -r test
```

### Production Site

```console
python setup.py sdist upload -r pypi
```